@@ -25,6 +25,7 @@ def get_name():
 
 def setup_p2p_params(network_ver, p2p_port, p2p_accept=True,
                      p2p_udp_accept=True, sub_dir=None, f_debug=False):
+    """ setup general connection setting """
     if f_debug:
         Debug.P_EXCEPTION = True
         Debug.P_RECEIVE_MSG_INFO = True
@@ -54,6 +55,23 @@ def setup_p2p_params(network_ver, p2p_port, p2p_accept=True,
     V.P2P_UDP_ACCEPT = p2p_udp_accept
 
 
+def setup_tor_connection(proxy_host='127.0.0.1', port=9150, f_raise_error=True):
+    """ client connection to onion router """
+    # Typically, Tor listens for SOCKS connections on port 9050.
+    # Tor-browser listens on port 9150.
+    host_port = (proxy_host, port)
+    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    if V.P2P_ACCEPT or V.P2P_UDP_ACCEPT:
+        raise ConnectionError('P2P socket accept enable? tcp={} udp={}'
+                              .format(V.P2P_ACCEPT, V.P2P_UDP_ACCEPT))
+    if 0 != sock.connect_ex(host_port):
+        if f_raise_error:
+            raise ConnectionError('Cannot connect proxy by test.')
+    else:
+        V.TOR_CONNECTION = host_port
+    sock.close()
+
+
 def is_reachable(host, port):
     for res in socket.getaddrinfo(host, port, socket.AF_UNSPEC, socket.SOCK_STREAM):
         af, socktype, proto, canonname, host_port = res
@@ -77,5 +95,5 @@ def trim_msg(item, num):
 
 __all__ = [
     "get_version", "get_name", "is_reachable",
-    "setup_p2p_params", "trim_msg",
+    "setup_tor_connection", "setup_p2p_params", "trim_msg",
 ]
